# Datasets Module

The `wandas.datasets` module provides sample data that can be used for testing and demonstrations.

## Sample Data

Provides sample audio data that can be used for testing and demonstrations.

::: wandas.datasets.sample_data
